@@ -1171,10 +1171,9 @@ Returns t if checkout was successful, nil otherwise."
 		      "Next action on" 
 		      ))
 		   ;; these are all for RCS and SCCS
-		   ((not (setq owner (vc-file-owner file)))
-		    ;; #### - ugh!  this is broken.
-		    ;; vc-file-owner is not a suitable
-		    ;; substitute for vc-locking-user.
+		   ((not (setq owner (vc-locking-user file)))
+		    ;; VC locking user is faster now. vc-file-owner
+		    ;; is superceded by incompatible FSF version (JV).
 		    "Check out File")
 		   ((not (string-equal owner (user-login-name)))
 		    "Steal File Lock")
